@@ -47,4 +47,9 @@ sub scan{
 }
 no Moose;
 1;
-		
\ No newline at end of file
+
+__END__
+
+=head1 
+For more information go to L<P50Tools>.
+=cut
