@@ -1,5 +1,5 @@
 use P50Tools;
 
 my $p = P50Tools::LFIScan->new();
-$p->target('www.itapursnga.net.br');
+$p->target('my.target.lan');
 $p->scan;
