@@ -1,6 +1,6 @@
 use P50Tools;
 
 my $p = P50Tools::Packs->new();
-$p->target('www.google.com.br');
+$p->target('my.target.lan');
 $p->door(80);
 $p->send;
