@@ -1,7 +1,7 @@
 use P50Tools;
 
 my $p = P50Tools::RandonDoors->new();
-$p->target('www.google.com.br');
+$p->target('my.target.lan');
 $p->ini(78);
 $p->end(82);
 $p->timeout(20);
